<?php
class Application_Model_PartnerMapper
{
	protected $_dbTable;

	public function setDbTable($dbTable)
	{
		if (is_string($dbTable)) {
			$dbTable = new $dbTable();
		}
		if (!$dbTable instanceof Zend_Db_Table_Abstract) {
			throw new Exception('Invalid table data gateway provided');
		}
		$this->_dbTable = $dbTable;
		return $this;
	}

	public function getDbTable()
	{
		if (null === $this->_dbTable) {
			$this->setDbTable('Application_Model_DbTable_Partner');
		}
		return $this->_dbTable;
	}

	public function save(Application_Model_Partner $partner)
	{
		$data = array(
			'title' => $partner->getTitle(),
			'logo' => $partner->getLogo(),
            'www' => $partner->getWww(),
			'active' => $partner->getActive(),

		);

		if (null === ($id = $partner->getId())) {
			unset($data['id']);
			return $this->getDbTable()->insert($data);
		} else {
			return $this->getDbTable()->update($data, array('id = ?' => $id));
		}
	}
	
    public function delete($partnerId)
	{
		return $this->getDbTable()->delete('id = '.$partnerId);
	}

	public function find($id, Application_Model_Partner $partner)
	{
		$result = $this->getDbTable()->find($id);
		if (0 == count($result)) {
			return false;
		}
		
		$row = $result->current();
		
		$partner->setId($row->id)
		->setTitle($row->title)
		->setLogo($row->logo)
		->setWww($row->www)
		->setActive($row->active);

	}
	
	public function fetchAll()
	{
	    $select = $this->getDbTable()->select()
	    ->order('id desc');
	    $resultSet = $this->getDbTable()->fetchAll($select);
		$entries   = array();
		foreach ($resultSet as $row) {
			$entry = new Application_Model_Partner();
			$entry->setId($row->id)
			->setTitle($row->title)
			->setLogo($row->logo)
			->setWww($row->www)
			->setActive($row->active);
			$entries[] = $entry;
		}
		return $entries;
	}
	
	public function fetchAllActive()
	{
		$select = $this->getDbTable()->select()
		->where('active = ?', 'Y')
		->order('id desc');
		$resultSet = $this->getDbTable()->fetchAll($select);
		$entries   = array();
		foreach ($resultSet as $row) {
			$entry = new Application_Model_Partner();
			$entry->setId($row->id)
			->setTitle($row->title)
			->setLogo($row->logo)
			->setWww($row->www)
			->setActive($row->active);
			$entries[] = $entry;
		}
		return $entries;
	}
	
}