<?php
class Application_Model_ProductCategoriesMapper
{
	protected $_dbTable;

	public function setDbTable($dbTable)
	{
		if (is_string($dbTable)) {
			$dbTable = new $dbTable();
		}
		if (!$dbTable instanceof Zend_Db_Table_Abstract) {
			throw new Exception('Invalid table data gateway provided');
		}
		$this->_dbTable = $dbTable;
		return $this;
	}

	public function getDbTable()
	{
		if (null === $this->_dbTable) {
			$this->setDbTable('Application_Model_DbTable_ProductCategories');
		}
		return $this->_dbTable;
	}

	public function find($id, Application_Model_ProductCategories $productCategory)
	{
		$result = $this->getDbTable()->find($id);
		if (0 == count($result)) {
			return;
		}
		$row = $result->current();
		$productCategory->setId($row->id)
		->setProductId($row->product_id)
		->setProductCategoryId($row->product_category_id);
	}
	
	public function save(Application_Model_ProductCategories $productCategory)
	{
		$data = array(
	            'product_id' => $productCategory->getProductId(),
	            'product_category_id' => $productCategory->getProductCategoryId(),
		);
	
		if (null === ($id = $productCategory->getId())) {
			unset($data['id']);
			return $this->getDbTable()->insert($data);
		} else {
			return $this->getDbTable()->update($data, array('id = ?' => $id));
		}
	}
	
	public function delete($productId)
	{
		return $this->getDbTable()->delete('product_id = '.$productId);
	}
	
	public function fetchAll()
	{
	    $select = $this->getDbTable()->select()
	    ->order('id asc');
	    $resultSet = $this->getDbTable()->fetchAll($select);
		$entries   = array();
		foreach ($resultSet as $row) {
			$entry = new Application_Model_ProductCategories();
			$entry->setId($row->id)
			->setProductId($row->product_id)
			->setProductCategoryId($row->product_category_id);
			$entries[] = $entry;
		}
		return $entries;
	}
	
	public function fetchByProduct($productId)
	{
		$select = $this->getDbTable()->select()
		->where('product_id = ?', $productId)
		->order('id asc');
		$resultSet = $this->getDbTable()->fetchAll($select);
		$entries   = array();
		foreach ($resultSet as $row) {
			$entry = new Application_Model_ProductCategories();
			$entry->setId($row->id)
			->setProductId($row->product_id)
			->setProductCategoryId($row->product_category_id);
			$entries[] = $entry;
		}
		return $entries;
	}
}