<?php
class Application_Model_ProductRegisterUserMapper
{
	protected $_dbTable;

	public function setDbTable($dbTable)
	{
		if (is_string($dbTable)) {
			$dbTable = new $dbTable();
		}
		if (!$dbTable instanceof Zend_Db_Table_Abstract) {
			throw new Exception('Invalid table data gateway provided');
		}
		$this->_dbTable = $dbTable;
		return $this;
	}

	public function getDbTable()
	{
		if (null === $this->_dbTable) {
			$this->setDbTable('Application_Model_DbTable_ProductRegisterUser');
		}
		return $this->_dbTable;
	}

	public function save(Application_Model_ProductRegisterUser $productRegisterUser)
	{
		$data = array(
			'product_register_id' => $productRegisterUser->getProductRegisterId(),
            'firstname' => $productRegisterUser->getFirstname(),
            'lastname' => $productRegisterUser->getLastname(),
            'position' => $productRegisterUser->getPosition(),
			'tel' => $productRegisterUser->getTel(),
			'email' => $productRegisterUser->getEmail(),
			'session' => $productRegisterUser->getSession(),
			'accredited' => $productRegisterUser->getAccredited(),

		);

		if (null === ($id = $productRegisterUser->getId())) {
			unset($data['id']);
			return $this->getDbTable()->insert($data);
		} else {
			return $this->getDbTable()->update($data, array('id = ?' => $id));
		}
	}
	
    public function delete($productId)
	{
		return $this->getDbTable()->delete('id = '.$productId);
	}

	public function find($id, Application_Model_ProductRegisterUser $productRegisterUser)
	{
		$result = $this->getDbTable()->find($id);
		if (0 == count($result)) {
			return false;
		}
		$row = $result->current();
		
		$productRegisterUser->setId($row->id)
			->setProductRegisterId($row->product_register_id)
			->setFirstname($row->firstname)
			->setLastname($row->lastname)
			->setPosition($row->position)
			->setTel($row->tel)
			->setEmail($row->email)
			->setSession($row->session)
			->setAccredited($row->accredited);
		
		return true;
	}
	
	public function fetchUsers($productRegisterId,$accredited=false)
	{
		$select = $this->getDbTable()->select()
		->where("product_register_id = ?", $productRegisterId)
		->order('id asc');
		if($accredited)
			$select->where("accredited = ?", "Y");
			
		$resultSet = $this->getDbTable()->fetchAll($select);
		$entries   = array();
		foreach ($resultSet as $row) {
			$entry = new Application_Model_ProductRegisterUser();
			$entry->setId($row->id)
			->setProductRegisterId($row->product_register_id)
			->setFirstname($row->firstname)
			->setLastname($row->lastname)
			->setPosition($row->position)
			->setTel($row->tel)
			->setEmail($row->email)
			->setSession($row->session)
			->setAccredited($row->accredited);
	
			$entries[] = $entry;
		}
		return $entries;
	}
	
	
	public function fetchAll()
	{
	    $select = $this->getDbTable()->select()
	   ->order('term_from asc');
	    $resultSet = $this->getDbTable()->fetchAll($select);
		$entries   = array();
		foreach ($resultSet as $row) {
			$entry = new Application_Model_Product();
			$entry->setId($row->id)
		->setProductType($row->product_type)
		->setSlug($row->slug)
		->setTitle1($row->title1)
		->setTitle2($row->title2)
		->setTitle3($row->title3)
		->setTitle4($row->title4)
		->setLogo($row->logo)
		->setCity($row->city)
		->setTermFrom($row->term_from)
		->setTermTo($row->term_to)
		->setTitleSmall1($row->title_small1)
		->setTitleSmall2($row->title_small2)
		->setPdf($row->pdf)
		->setProgram($row->program)
		->setPlace($row->place)
		->setPrice1($row->price1)
		->setPrice2($row->price2)
		->setPriceTo($row->price_to)
		->setActive($row->active)
		->setCreated($row->created)
		->setTemplate($row->template);
		
		$entries[] = $entry;
		}
		return $entries;
	}
	
	public function fetchAllActiveForIndex()
	{
		$select = $this->getDbTable()->select()
		->where('active = ?', 'Y')
		->where('product_type IN (1,2,3)')
		->order('term_from asc');
		$resultSet = $this->getDbTable()->fetchAll($select);
		$entries   = array();
		foreach ($resultSet as $row) {
			$entry = new Application_Model_Product();
			$entry->setId($row->id)
			->setProductType($row->product_type)
			->setSlug($row->slug)
			->setTitle1($row->title1)
			->setTitle2($row->title2)
			->setTitle3($row->title3)
			->setTitle4($row->title4)
			->setLogo($row->logo)
			->setCity($row->city)
			->setTermFrom($row->term_from)
			->setTermTo($row->term_to)
			->setTitleSmall1($row->title_small1)
			->setTitleSmall2($row->title_small2)
			->setPdf($row->pdf)
			->setProgram($row->program)
			->setPlace($row->place)
			->setPrice1($row->price1)
			->setPrice2($row->price2)
			->setPriceTo($row->price_to)
			->setActive($row->active)
			->setCreated($row->created)
			->setTemplate($row->template);
			$entries[] = $entry;
		}
		return $entries;
	}
	
	public function fetchAllByType($type)
	{
		$select = $this->getDbTable()->select()
		->where("product_type = ?", $type)
		->order('term_from asc');
		$resultSet = $this->getDbTable()->fetchAll($select);
		$entries   = array();
		foreach ($resultSet as $row) {
			$entry = new Application_Model_Product();
			$entry->setId($row->id)
			->setProductType($row->product_type)
			->setSlug($row->slug)
			->setTitle1($row->title1)
			->setTitle2($row->title2)
			->setTitle3($row->title3)
			->setTitle4($row->title4)
			->setLogo($row->logo)
			->setCity($row->city)
			->setTermFrom($row->term_from)
			->setTermTo($row->term_to)
			->setTitleSmall1($row->title_small1)
			->setTitleSmall2($row->title_small2)
			->setPdf($row->pdf)
			->setProgram($row->program)
			->setPlace($row->place)
			->setPrice1($row->price1)
			->setPrice2($row->price2)
			->setPriceTo($row->price_to)
			->setActive($row->active)
			->setCreated($row->created)
			->setTemplate($row->template);
	
			$entries[] = $entry;
		}
		return $entries;
	}
	
	public function fetchAllActiveByType($type, $order=false)
	{
		$select = $this->getDbTable()->select()
		->where("product_type = ?", $type)
		->where("active = 'Y'");
		if(!$order)
			$select->order('term_from asc');
		elseif($order)
			$select->order($order);
		$resultSet = $this->getDbTable()->fetchAll($select);
		$entries   = array();
		foreach ($resultSet as $row) {
			$entry = new Application_Model_Product();
			$entry->setId($row->id)
			->setProductType($row->product_type)
			->setSlug($row->slug)
			->setTitle1($row->title1)
			->setTitle2($row->title2)
			->setTitle3($row->title3)
			->setTitle4($row->title4)
			->setLogo($row->logo)
			->setCity($row->city)
			->setTermFrom($row->term_from)
			->setTermTo($row->term_to)
			->setTitleSmall1($row->title_small1)
			->setTitleSmall2($row->title_small2)
			->setPdf($row->pdf)
			->setProgram($row->program)
			->setPlace($row->place)
			->setPrice1($row->price1)
			->setPrice2($row->price2)
			->setPriceTo($row->price_to)
			->setActive($row->active)
			->setCreated($row->created)
			->setTemplate($row->template);
	
			$entries[] = $entry;
		}
		return $entries;
	}
	
	
	
	
	
	
	

}
