<?php
class Application_Model_ProductSpeakerMapper
{
	protected $_dbTable;

	public function setDbTable($dbTable)
	{
		if (is_string($dbTable)) {
			$dbTable = new $dbTable();
		}
		if (!$dbTable instanceof Zend_Db_Table_Abstract) {
			throw new Exception('Invalid table data gateway provided');
		}
		$this->_dbTable = $dbTable;
		return $this;
	}

	public function getDbTable()
	{
		if (null === $this->_dbTable) {
			$this->setDbTable('Application_Model_DbTable_ProductSpeaker');
		}
		return $this->_dbTable;
	}

	public function save(Application_Model_ProductSpeaker $speaker)
	{
		$data = array(
            'product_id' => $speaker->getProductId(),
			'active' => $speaker->getActive(),
			'title' => $speaker->getTitle(),
			'function' => $speaker->getFunction(),
			'logo' => $speaker->getLogo(),
            'www' => $speaker->getWww(),
			'desc' => $speaker->getDesc(),
			'type' => $speaker->getType(),
		   
		    
		);

		if (null === ($id = $speaker->getId())) {
			unset($data['id']);
			return $this->getDbTable()->insert($data);
		} else {
			return $this->getDbTable()->update($data, array('id = ?' => $id));
		}
	}
	
    public function delete($speakerId)
	{
		return $this->getDbTable()->delete('id = '.$speakerId);
	}

	public function find($id, Application_Model_ProductSpeaker $speaker)
	{
		$result = $this->getDbTable()->find($id);
		if (0 == count($result)) {
			return false;
		}
		$row = $result->current();
		
		$speaker->setId($row->id)
		->setProductId($row->product_id)
		->setActive($row->active)
		->setTitle($row->title)
		->setFunction($row->function)
		->setLogo($row->logo)
		->setWww($row->www)
		->setDesc($row->desc)
		->setType($row->type);

	}
	
	public function fetchAll()
	{
	    $select = $this->getDbTable()->select()
	    ->order('id desc');
	    $resultSet = $this->getDbTable()->fetchAll($select);
		$entries   = array();
		foreach ($resultSet as $row) {
			$entry = new Application_Model_ProductSpeaker();
			$entry->setId($row->id)
			->setProductId($row->product_id)
			->setActive($row->active)
			->setTitle($row->title)
			->setFunction($row->function)
			->setLogo($row->logo)
			->setWww($row->www)
			->setDesc($row->desc)
			->setType($row->type);
			$entries[] = $entry;
		}
		return $entries;
	}
	
	public function fetchAllByType($productId, $type)
	{
		$select = $this->getDbTable()->select()
		->where('product_id = ?', $productId)
		->where('type= ?', $type)
		->order('id desc');
		$resultSet = $this->getDbTable()->fetchAll($select);
		$entries   = array();
		foreach ($resultSet as $row) {
			$entry = new Application_Model_ProductSpeaker();
			$entry->setId($row->id)
			->setProductId($row->product_id)
			->setActive($row->active)
			->setTitle($row->title)
			->setFunction($row->function)
			->setLogo($row->logo)
			->setWww($row->www)
			->setDesc($row->desc)
			->setType($row->type);
			$entries[] = $entry;
		}
		return $entries;
	}
	
	public function fetchAllActiveByType($productId, $type)
	{
		$select = $this->getDbTable()->select()
		->where('product_id = ?', $productId)
		->where('type= ?', $type)
		->where('active= "Y"')
		->order('id desc');
		$resultSet = $this->getDbTable()->fetchAll($select);
		$entries   = array();
		foreach ($resultSet as $row) {
			$entry = new Application_Model_ProductSpeaker();
			$entry->setId($row->id)
			->setProductId($row->product_id)
			->setActive($row->active)
			->setTitle($row->title)
			->setFunction($row->function)
			->setLogo($row->logo)
			->setWww($row->www)
			->setDesc($row->desc)
			->setType($row->type);
			$entries[] = $entry;
		}
		return $entries;
	}
	
}